Index: content/browser/renderer_host/render_process_host.h |
diff --git a/content/browser/renderer_host/render_process_host.h b/content/browser/renderer_host/render_process_host.h |
index 9d3b8fc7f2f314c7cbd43274b8861d8c9b75711c..c8dfe013fba436f0ef321be05426f78a8f39dcbb 100644 |
--- a/content/browser/renderer_host/render_process_host.h |
+++ b/content/browser/renderer_host/render_process_host.h |
@@ -17,7 +17,7 @@ |
#include "ui/gfx/surface/transport_dib.h" |
class Profile; |
-struct ViewMsg_ClosePage_Params; |
+struct ViewMsg_SwapOut_Params; |
namespace base { |
class SharedMemory; |
@@ -175,12 +175,12 @@ class RenderProcessHost : public IPC::Channel::Sender, |
// the specified render widget. |
virtual void CancelResourceRequests(int render_widget_id) = 0; |
// Called on the UI thread to simulate a ClosePage_ACK message to the |
// ResourceDispatcherHost. Necessary for a cross-site request, in the case |
// that the original RenderViewHost is not live and thus cannot run an |
- // onunload handler. |
- virtual void CrossSiteClosePageACK( |
- const ViewMsg_ClosePage_Params& params) = 0; |
+ // unload handler. |
+ virtual void CrossSiteSwapOutACK( |
+ const ViewMsg_SwapOut_Params& params) = 0; |
// Called on the UI thread to wait for the next UpdateRect message for the |
// specified render widget. Returns true if successful, and the msg out- |
@@ -175,12 +175,12 @@ class RenderProcessHost : public IPC::Channel::Sender, |
// the specified render widget. |
virtual void CancelResourceRequests(int render_widget_id) = 0; |
- // Called on the UI thread to simulate a ClosePage_ACK message to the |
+ // Called on the UI thread to simulate a SwapOut_ACK message to the |
// ResourceDispatcherHost. Necessary for a cross-site request, in the case |
// that the original RenderViewHost is not live and thus cannot run an |